######
Readme
######

``FPGAFlow`` is a python script to handle a complete FPGA design flow where the design files, libraries and
supplementary tools are stored in a source code repository.

`Source Code Repository <https://bitbucket.org/mjroberts/fpgaflow/src/master/docs/>`_
`Documentation <https://fpgaflow.readthedocs.io/en/latest/index.html>`_

License
-------

`BSD`_ © 2018-2019 Science and Technology Facilities Council & contributors

.. _BSD: LICENSE
